@@ -53,7 +53,7 @@ class Connection(object):
             raise InterfaceError(error)
 
     def _parse_header(self, header, request_id):
-        logging.debug('got data %r' % header)
+        logger.debug('got data %r' % header)
         length = int(struct.unpack("<i", header[:4])[0])
         _request_id = struct.unpack("<i", header[8:12])[0]
 
@@ -62,8 +62,8 @@ class Connection(object):
 
         operation = 1 # who knows why
         assert operation == struct.unpack("<i", header[12:])[0]
-        logging.debug('%s' % length)
-        logging.debug('waiting for another %d bytes' % (length - 16))
+        logger.debug('%s' % length)
+        logger.debug('waiting for another %d bytes' % (length - 16))
 
         return length
 
